package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.ElecValencyConfig;

import java.util.List;

/**
 * 电价配置Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-23
 */
public interface ElecValencyConfigMapper {
    /**
     * 查询电价配置
     *
     * @param id 电价配置主键
     * @return 电价配置
     */
    ElecValencyConfig selectElecValencyConfigById(Long id);

    /**
     * 查询电价配置列表
     *
     * @param elecValencyConfig 电价配置
     * @return 电价配置集合
     */
    List<ElecValencyConfig> selectElecValencyConfigList(ElecValencyConfig elecValencyConfig);

    /**
     * 新增电价配置
     *
     * @param elecValencyConfig 电价配置
     * @return 结果
     */
    int insertElecValencyConfig(ElecValencyConfig elecValencyConfig);

    /**
     * 修改电价配置
     *
     * @param elecValencyConfig 电价配置
     * @return 结果
     */
    int updateElecValencyConfig(ElecValencyConfig elecValencyConfig);

    /**
     * 删除电价配置
     *
     * @param id 电价配置主键
     * @return 结果
     */
    int deleteElecValencyConfigById(Long id);

    /**
     * 批量删除电价配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteElecValencyConfigByIds(Long[] ids);
}
