package com.ruoyi.ems.service;

import java.util.List;

import com.ruoyi.ems.domain.ElecValencyConfig;

/**
 * 电价配置Service接口
 * 
 * @author ruoyi
 * @date 2024-07-23
 */
public interface IElecValencyConfigService
{
    /**
     * 查询电价配置
     * 
     * @param id 电价配置主键
     * @return 电价配置
     */
     ElecValencyConfig selectElecValencyConfigById(Long id);

    /**
     * 查询电价配置列表
     * 
     * @param elecValencyConfig 电价配置
     * @return 电价配置集合
     */
     List<ElecValencyConfig> selectElecValencyConfigList(ElecValencyConfig elecValencyConfig);

    /**
     * 新增电价配置
     * 
     * @param elecValencyConfig 电价配置
     * @return 结果
     */
     int insertElecValencyConfig(ElecValencyConfig elecValencyConfig);

    /**
     * 修改电价配置
     * 
     * @param elecValencyConfig 电价配置
     * @return 结果
     */
     int updateElecValencyConfig(ElecValencyConfig elecValencyConfig);

    /**
     * 批量删除电价配置
     * 
     * @param ids 需要删除的电价配置主键集合
     * @return 结果
     */
     int deleteElecValencyConfigByIds(Long[] ids);

    /**
     * 删除电价配置信息
     * 
     * @param id 电价配置主键
     * @return 结果
     */
     int deleteElecValencyConfigById(Long id);
}
